netapp_ontap.models.audit_events API documentation
Description: Copyright &copy; 2020 NetApp Inc. All rights reserved.

# Module `netapp_ontap.models.audit_events`

Copyright © 2020 NetApp Inc. All rights reserved.

## Classes

`class AuditEventsSchema (*, only: typing.Union = None, exclude: typing.Union = (), many: bool = False, context: typing.Dict = None, load_only: typing.Union = (), dump_only: typing.Union = (), partial: typing.Union = False, unknown: str = None)`

  The fields of the AuditEvents object

  ### Ancestors

  - netapp_ontap.resource.ResourceSchema
  - marshmallow.schema.Schema
  - marshmallow.base.SchemaABC

  ### Class variables

  `authorization_policy GET POST PATCH`

    Authorization policy change events

  `cap_staging GET POST PATCH`

    Central access policy staging events

  `cifs_logon_logoff GET POST PATCH`

    CIFS logon and logoff events

  `file_operations GET POST PATCH`

    File operation events

  `file_share GET POST PATCH`

    File share category events

  `security_group GET POST PATCH`

    Local security group management events

  `user_account GET POST PATCH`

    Local user account management events